UserProfile class
- Annotations
-
- @freezed
Constructors
-
UserProfile({String? country, @JsonKey.new(name: 'display_name') String? displayName, String? email, @JsonKey.new(name: 'explicit_content') ExplicitContent? explicitContent, @JsonKey.new(name: 'external_urls') ExternalUrls? externalUrls, Followers? followers, String? href, String? id, String? uri, String? product, String? type, List<
Image> ? images}) -
constfactory
-
UserProfile.fromJson(Map<
String, Object?> json) -
factory
Properties
-
copyWith
→ $UserProfileCopyWith<
UserProfile> -
no setterinherited
- country → String?
-
no setterinherited
- displayName → String?
-
no setterinherited
- email → String?
-
no setterinherited
- explicitContent → ExplicitContent?
-
no setterinherited
- externalUrls → ExternalUrls?
-
no setterinherited
- followers → Followers?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- href → String?
-
no setterinherited
- id → String?
-
no setterinherited
-
images
→ List<
Image> ? -
no setterinherited
- product → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
no setterinherited
- uri → String?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited